Class: SwaggerPetstoreOpenApi30::ApiResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/swagger_petstore_open_api30/http/api_response.rb,
lib/swagger_petstore_open_api30/models/api_response.rb

Overview

ApiResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, type: SKIP, message: SKIP, additional_properties: nil) ⇒ ApiResponse

The constructor

Parameters:

  • http_response (HttpResponse)

    The original, raw response from the api.

  • data (Object)

    The data field specified for the response.

  • errors (Array<String>)

    Any errors returned by the server.



13
14
15
16
17
# File 'lib/swagger_petstore_open_api30/http/api_response.rb', line 13

def initialize(http_response,
               data: nil,
               errors: nil)
  super
end

Instance Attribute Details

#codeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 14

def code
  @code
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 22

def message
  @message
end

#typeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 18

def type
  @type
end

Class Method Details

.from_element(root) ⇒ Object



81
82
83
84
85
86
87
88
89
90
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 81

def self.from_element(root)
  code = XmlUtilities.from_element(root, 'code', Integer)
  type = XmlUtilities.from_element(root, 'type', String)
  message = XmlUtilities.from_element(root, 'message', String)

  new(code: code,
      type: type,
      message: message,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ApiResponse.new(code: code,
                  type: type,
                  message: message,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['type'] = 'type'
  @_hash['message'] = 'message'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 34

def self.optionals
  %w[
    code
    type
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, type: #{@type.inspect}, message:"\
  " #{@message.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, type: #{@type}, message: #{@message},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



92
93
94
95
96
97
98
99
100
101
102
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 92

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'code', code)
  XmlUtilities.add_as_subelement(doc, root, 'type', type)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end