Class: SwaggerPetstoreOpenApi30::Tag

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/swagger_petstore_open_api30/models/tag.rb

Overview

Tag Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, name: SKIP, additional_properties: nil) ⇒ Tag

Returns a new instance of Tag.



41
42
43
44
45
46
47
48
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 41

def initialize(id: SKIP, name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @name = name unless name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 14

def id
  @id
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 18

def name
  @name
end

Class Method Details

.from_element(root) ⇒ Object



71
72
73
74
75
76
77
78
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 71

def self.from_element(root)
  id = XmlUtilities.from_element(root, 'id', Integer)
  name = XmlUtilities.from_element(root, 'name', String)

  new(id: id,
      name: name,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Tag.new(id: id,
          name: name,
          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 29

def self.optionals
  %w[
    id
    name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



80
81
82
83
84
85
86
87
88
89
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 80

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'name', name)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end